@@ -88,6 +88,25 @@ def generate_job(
     process_response(r)
 
 
+@app.command()
+def fetch_job_preview(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
+    """Fetch output of generate dry-run.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.get(
+            ctx,
+            "{spark_url}/preview".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+        )
+
+    r = _request(ctx)
+
+    process_response(r)
+
+
 @app.command()
 def job_history(
     ctx: typer.Context,
@@ -389,6 +408,77 @@ def unschedule_job(
     process_response(r)
 
 
+@app.command()
+def stream_job(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    trigger_interval: str = typer.Option(..., "--trigger", "-t",
+                                         help='Trigger interval in spark format (e.g. "30 seconds")'),
+):
+    """Run an infinite spark job.
+
+    For streaming data product spark job will be created with given trigger interval.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        params = {"trigger_interval": trigger_interval}
+
+        return util.post(
+            ctx,
+            "{spark_url}/streaming".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            params=params,
+        )
+
+    r = _request(ctx)
+    process_response(r)
+
+
+@app.command()
+def restream_job(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+    trigger_interval: str = typer.Option(..., "--trigger", "-t",
+                                         help='Trigger interval in spark format (e.g. "30 seconds")'),
+):
+    """Update an infinite spark job.
+
+    For streaming data product spark job will be removed and recreated with given trigger interval.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        params = {"trigger_interval": trigger_interval}
+
+        return util.put(
+            ctx,
+            "{spark_url}/streaming".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+            params=params,
+        )
+
+    r = _request(ctx)
+    process_response(r)
+
+
+@app.command()
+def unstream_job(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
+    """Pause an infinite spark job.
+
+    For streaming data product spark job will be removed and recreated with trigger interval "once".
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+
+        return util.delete(
+            ctx,
+            "{spark_url}/streaming".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
+        )
+
+    r = _request(ctx)
+    process_response(r)
+
+
 @secret_app.command()
 def add(
     ctx: typer.Context,
